
# Slot: all_of


holds if all of the expressions hold

URI: [linkml:slot_expression_all_of](https://w3id.org/linkml/slot_expression_all_of)


## Domain and Range

slot_expression &#8594;  <sub>0..\*</sub> anonymous_slot_expression

## Parents

 *  is_a: all_of

## Children


## Used by

 * anonymous_slot_expression
 * slot_definition
 * slot_expression

## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | sh:and |

